@@ -1,6 +1,6 @@
 structure(list(project_id = c(33L, 34L, 36L, 37L, 38L, 39L, 40L, 
 41L, 42L, 43L, 44L, 45L, 46L, 47L, 48L, 49L, 49L, 50L, 51L, 52L, 
-53L, 54L, 55L, 56L, 57L, 58L, 59L, 60L, 61L, 62L), project_title = c("REDCapR: simple", 
+53L, 54L, 55L, 56L, 57L, 58L, 59L, 60L, 61L, 62L, 63L), project_title = c("REDCapR: simple", 
 "REDCapR: longitudinal", "REDCapR: simple-write", "REDCapR: russian", 
 "REDCapR: empty rows", "REDCapR: single-column", "REDCapR: super-wide-1", 
 "REDCapR: survey", "REDCapR: clinical-trial-1", "REDCapR: nonnumeric-record-id", 
@@ -10,50 +10,34 @@ structure(list(project_id = c(33L, 34L, 36L, 37L, 38L, 39L, 40L,
 "REDCapR: super-wide-3", "REDCapR: repeating-instruments-sparse", 
 "REDCapR: arm-single-delete", "REDCapR: arm-multiple-delete", 
 "REDCapR: arm-single-longitudinal", "REDCapR: decimal-comma-and-dot", 
-"REDCapR: comma", "REDCapR: decimal-dot", "REDCapR: valiation-types-1", 
-"REDCapR: blank-for-gray-status", "REDCapR: checkboxes-1", "REDCapR: vignette-repeating"
-), creation_time = structure(c(1728609678, 1728610817, 1728659834, 
-1728662057, 1728662448, 1728678073, 1728681914, 1728682668, 1728684539, 
-1728684968, 1728685335, 1728686037, 1728687457, 1728688739, 1728738760, 
-1728743784, 1728743784, 1728744878, 1728761607, 1728765017, 1728766845, 
-1728767641, 1728769237, 1728774178, 1728777080, 1728777990, 1728780635, 
-1728784212, 1728793066, 1728828021), tzone = "America/Chicago", class = c("POSIXct", 
-"POSIXt")), production_time = structure(c(NA_real_, NA_real_, 
-NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
-NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
-NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
-NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
+"REDCapR: decimal-comma", "REDCapR: decimal-dot", "REDCapR: valiation-types-1", 
+"REDCapR: blank-for-gray-status", "REDCapR: checkboxes-1", "REDCapR: vignette-repeating", 
+"REDCapR: file-repo"), creation_time = structure(c(1728609678, 
+1728610817, 1728659834, 1728662057, 1728662448, 1728678073, 1728681914, 
+1728682668, 1728684539, 1728684968, 1728685335, 1728686037, 1728687457, 
+1728688739, 1728738760, 1728743784, 1728743784, 1728744878, 1728761607, 
+1728765017, 1728766845, 1728767641, 1728769237, 1728774178, 1728777080, 
+1728777990, 1728780635, 1728784212, 1728793066, 1728828021, 1729865983
 ), tzone = "America/Chicago", class = c("POSIXct", "POSIXt")), 
-    in_production = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    production_time = structure(c(NA_real_, NA_real_, NA_real_, 
+    NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
+    NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
+    NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
+    NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
+    NA_real_, NA_real_, NA_real_, NA_real_), tzone = "America/Chicago", class = c("POSIXct", 
+    "POSIXt")), in_production = c(FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_language = c("English", 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE
+    ), project_language = c("English", "English", "English", 
     "English", "English", "English", "English", "English", "English", 
     "English", "English", "English", "English", "English", "English", 
     "English", "English", "English", "English", "English", "English", 
     "English", "English", "English", "English", "English", "English", 
-    "English", "English", "English", "English", "English"), purpose = c(4L, 
+    "English", "English", "English", "English"), purpose = c(4L, 
     4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 
-    4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L), 
-    purpose_other = c(NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_), project_notes = c(NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_), custom_record_label = c(NA, NA, NA, NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, NA, NA, "[height]; [weight]; [bmi]"
-    ), secondary_unique_field = c(NA_character_, NA_character_, 
+    4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L
+    ), purpose_other = c(NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
@@ -61,32 +45,47 @@ NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_
-    ), is_longitudinal = c(FALSE, TRUE, FALSE, FALSE, FALSE, 
+    ), project_notes = c(NA, NA, NA, NA, NA, NA, NA, NA, "Generated and contributed by Peter Higgins at University of Michigan School of Medicine", 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
+    NA, NA, NA, NA, NA, NA, NA), custom_record_label = c(NA, 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "[height]; [weight]; [bmi]", 
+    NA), secondary_unique_field = c(NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_), is_longitudinal = c(FALSE, TRUE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), has_repeating_instruments_or_events = c(FALSE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
+    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE
+    ), has_repeating_instruments_or_events = c(FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, TRUE), surveys_enabled = c(FALSE, FALSE, FALSE, FALSE, 
+    FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    TRUE, FALSE), surveys_enabled = c(FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
-    scheduling_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), record_autonumbering_enabled = c(TRUE, 
-    FALSE, TRUE, FALSE, TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, 
-    FALSE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, TRUE, 
-    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
-    TRUE), randomization_enabled = c(FALSE, FALSE, FALSE, FALSE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE
+    ), scheduling_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
-    ddp_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    record_autonumbering_enabled = c(TRUE, FALSE, TRUE, FALSE, 
+    TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, TRUE, TRUE, 
+    TRUE, FALSE, FALSE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
+    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE), randomization_enabled = c(FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
     FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_irb_number = c(NA_character_, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    FALSE, FALSE, FALSE), ddp_enabled = c(FALSE, FALSE, FALSE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
+    FALSE), project_irb_number = c(NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
@@ -101,27 +100,27 @@ NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_
-    ), project_pi_firstname = c(NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_), project_pi_firstname = c(NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_
-    ), project_pi_lastname = c(NA_character_, NA_character_, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_), project_pi_lastname = c(NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_, NA_character_, NA_character_, NA_character_
-    ), display_today_now_button = c(TRUE, TRUE, TRUE, TRUE, TRUE, 
+    NA_character_, NA_character_, NA_character_, NA_character_, 
+    NA_character_), display_today_now_button = c(TRUE, TRUE, 
     TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
     TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
-    TRUE, TRUE, TRUE, TRUE, TRUE), missing_data_codes = c(NA_character_, 
+    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE), missing_data_codes = c(NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
@@ -129,16 +128,8 @@ NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
     NA_character_, NA_character_, NA_character_, NA_character_, 
-    NA_character_), external_modules = c("redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
-    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity"
-    ), bypass_branching_erase_field_prompt = c("0", "0", "0", 
+    NA_character_, NA_character_), bypass_branching_erase_field_prompt = c("0", 
     "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
     "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
-    "0", "0", "0")), row.names = c(NA, -30L), class = c("tbl_df", 
+    "0", "0", "0", "0", "0", "0")), row.names = c(NA, -31L), class = c("tbl_df", 
 "tbl", "data.frame"))
